@@ -14,7 +14,7 @@ from simpleeval import EvalWithCompoundTypes
 from yaml import safe_dump, safe_load
 
 from .constants import APP_NAME
-from .exceptions import QueryError
+from .exceptions import QueryError, JiraSelectError
 from .types import (
     ConfigDict,
     ExpressionList,
@@ -140,13 +140,7 @@ def get_row_dict(row: Any) -> Dict[str, Any]:
 
     # Gather any top-level keys, too, to make sure we fetch any expansions
     for key in dir(row):
-        value = getattr(row, key)
-        if (
-            key != "fields"
-            and not key.startswith("_")
-            and not key.upper() == key
-            and not callable(value)
-        ):
+        if key != "fields" and not key.startswith("_") and not key.upper() == key:
             names[key] = getattr(row, key)
 
     return names
@@ -215,6 +209,10 @@ def get_field_data(
                 expression, names={"_": row, **row.as_dict()}, functions=functions,
             )
         )
+    except JiraSelectError:
+        # Re-raise these -- they can be used for alerting the user
+        # to a configuration problem or w/e
+        raise
     except (
         simpleeval.AttributeDoesNotExist,
         simpleeval.NameNotDefined,
@@ -227,4 +225,4 @@ def get_field_data(
             raise
         return None
     except Exception as e:
-        raise QueryError(str(e))
+        raise QueryError(f"{e}: {expression}")
